@@ -79,7 +79,7 @@ def description(desc):
         fs = open("README.md", 'w')
         fs.write(f"# {_Name}\n\n")
         fs.write(desc)
-        fs.write(f"\n\n# Importing {_Name}:\n\n**How to import {_Name} with no issues:**\n\n```python\nfrom {_Name} import main\n```")
+        fs.write(f"\n\n# Importing {_Name}:\n\n**How to import {_Name} with no issues:**\n\n```python\nimport {_Name}.main\n```")
         fs.close()
         
         system(f"mv README.md {f'{_Name}1'}")
@@ -885,6 +885,8 @@ For more information on this, and how to apply and follow the GNU AGPL, see
 
 
 def publish(uname, test=True):
+    """Publishes your module.
+    The one argument [uname] is your username. When you run the function, it will prompt your PyPI a password."""
     pwd = getpass("Your PyPI password: ")
     system("python3 -m pip install --upgrade twine")
     
